@@ -29,6 +29,7 @@ import (
 	"pkg.deepin.io/dde/startdde/display/utils"
 	gio "pkg.deepin.io/gir/gio-2.0"
 	"pkg.deepin.io/lib/dbusutil"
+	"pkg.deepin.io/lib/gsettings"
 )
 
 const (
@@ -48,6 +49,13 @@ const (
 	ColorTemperatureModeManual
 )
 
+const (
+	// 1：自动旋转；即未主动调用 SetRotation() 接口（由内部触发）发生的旋转操作，如根据重力传感器自动设定旋转方向
+	RotationFinishModeAuto uint8 = iota + 1
+	// 2：手动旋转；即主动调用 SetRotation() 接口完成旋转，如控制中心下拉框方式旋转屏幕
+	RotationFinishModeManual
+)
+
 const (
 	gsSchemaDisplay  = "com.deepin.dde.display"
 	gsKeyDisplayMode = "display-mode"
@@ -58,10 +66,12 @@ const (
 	gsKeyCustomMode             = "current-custom-mode"
 	gsKeyColorTemperatureMode   = "color-temperature-mode"
 	gsKeyColorTemperatureManual = "color-temperature-manual"
+	gsKeyRotateScreenTimeDelay  = "rotate-screen-time-delay"
 	customModeDelim             = "+"
 	monitorsIdDelimiter         = ","
 	defaultTemperatureMode      = ColorTemperatureModeNormal
 	defaultTemperatureManual    = 6500
+	defaultRotateScreenTimeDelay = 500
 
 	cmdTouchscreenDialogBin = "/usr/lib/deepin-daemon/dde-touchscreen-dialog"
 )
@@ -85,6 +95,14 @@ var (
 	}
 )
 
+var (
+	rotationScreenValue = map[string]uint16{
+		"normal": randr.RotationRotate0,
+		"left":   randr.RotationRotate270, // 屏幕重力旋转左转90
+		"right":  randr.RotationRotate90,  // 屏幕重力旋转右转90
+	}
+)
+
 type touchscreenMapValue struct {
 	OutputName string
 	Auto       bool
@@ -114,9 +132,12 @@ type Manager struct {
 	configTimestamp          x.Timestamp
 	settings                 *gio.Settings
 	monitorsId               string
-	isLaptop                 bool
 	modeChanged              bool
 	info                     ConnectInfo
+	rotationFinishChanged    bool
+	rotationScreenTimer      *time.Timer
+	hasBuiltinMonitor        bool
+	rotateScreenTimeDelay    int32
 
 	// dbusutil-gen: equal=nil
 	Monitors []dbus.ObjectPath
@@ -131,6 +152,9 @@ type Manager struct {
 	// dbusutil-gen: equal=nil
 	TouchMap       map[string]string
 	touchscreenMap map[string]touchscreenMapValue
+	// touch.uuid -> touchScreenDialog cmd
+	touchScreenDialogMap   map[string]*exec.Cmd
+	touchScreenDialogMutex sync.RWMutex
 
 	CurrentCustomId string
 	Primary         string
@@ -242,8 +266,8 @@ func newManager(service *dbusutil.Service) *Manager {
 	if err != nil {
 		logger.Warning(err)
 	}
-	if chassis == "laptop" {
-		m.isLaptop = true
+	if chassis == "laptop" || chassis == "all-in-one" {
+		m.hasBuiltinMonitor = true
 	}
 
 	m.settings = gio.NewSettings(gsSchemaDisplay)
@@ -254,6 +278,7 @@ func newManager(service *dbusutil.Service) *Manager {
 	m.CurrentCustomId = m.settings.GetString(gsKeyCustomMode)
 	m.gsColorTemperatureManual = m.settings.GetInt(gsKeyColorTemperatureManual)
 	m.gsColorTemperatureMode = m.settings.GetEnum(gsKeyColorTemperatureMode)
+	m.rotateScreenTimeDelay = m.settings.GetInt(gsKeyRotateScreenTimeDelay)
 	m.ColorTemperatureManual = defaultTemperatureManual
 	m.ColorTemperatureMode = defaultTemperatureMode
 
@@ -358,6 +383,7 @@ func newManager(service *dbusutil.Service) *Manager {
 			return
 		}
 		m.handleTouchscreenChanged()
+		m.showTouchscreenDialogs()
 	})
 	if err != nil {
 		logger.Warningf("prop active ConnectChanged failed! %v", err)
@@ -368,8 +394,7 @@ func newManager(service *dbusutil.Service) *Manager {
 
 // initBuiltinMonitor 初始化内置显示器。
 func (m *Manager) initBuiltinMonitor() {
-	// 只有笔记本 laptop 才有内置显示器
-	if !m.isLaptop {
+	if !m.hasBuiltinMonitor {
 		return
 	}
 	// 从配置文件获取内置显示器名称
@@ -468,7 +493,7 @@ func (m *Manager) applyDisplayMode(needInitColorTemperature bool) {
 		// 单屏情况
 		screenCfg := m.getScreenConfig()
 		config := new(SingleModeConfig)
-		if screenCfg.Single != nil {
+		if screenCfg.Single != nil && screenCfg.Single.Monitor != nil {
 			// 已有单屏配置
 			config = screenCfg.Single
 		} else {
@@ -535,6 +560,13 @@ func (m *Manager) init() {
 	// 重启 startdde 读取上一次设置，不需要重置色温。
 	m.applyDisplayMode(false)
 	m.listenEvent() // 等待 applyDisplayMode 执行完成再开启监听 X 事件
+	if m.builtinMonitor != nil {
+		m.listenSettingsChanged() // 监听旋转屏幕延时值
+		m.listenRotateSignal() // 监听屏幕旋转信号
+	} else {
+		// 没有内建屏,不监听内核信号
+		logger.Info("built-in screen does not exist")
+	}
 }
 
 // initColorTemperature 初始化色温设置，名字不太好，不在初始化时，也调用了。
@@ -1138,6 +1170,7 @@ func (m *Manager) apply() error {
 			logger.Debugf("disable crtc %v, it's outputs: %v", crtc, crtcInfo.Outputs)
 			err := m.disableCrtc(crtc, cfgTs)
 			if err != nil {
+				m.crtcMapMu.Unlock()
 				return err
 			}
 		}
@@ -1946,10 +1979,12 @@ func (m *Manager) removeTouchscreenByIdx(i int) {
 }
 
 func (m *Manager) removeTouchscreenByPath(path dbus.ObjectPath) {
+	touchScreenUUID := ""
 	i := -1
 	for index, v := range m.Touchscreens {
 		if v.path == path {
 			i = index
+			touchScreenUUID = v.uuid
 		}
 	}
 
@@ -1957,6 +1992,21 @@ func (m *Manager) removeTouchscreenByPath(path dbus.ObjectPath) {
 		return
 	}
 
+	if touchScreenUUID != "" {
+		m.touchScreenDialogMutex.RLock()
+		existCmd, ok := m.touchScreenDialogMap[touchScreenUUID]
+		m.touchScreenDialogMutex.RUnlock()
+		if ok && existCmd != nil && existCmd.Process != nil {
+			if existCmd.ProcessState == nil {
+				logger.Debug("to kill process of touchScreenDialog.")
+				err := existCmd.Process.Kill()
+				if err != nil {
+					logger.Warning("failed to kill process of touchScreenDialog, error:", err)
+				}
+			}
+		}
+	}
+
 	m.removeTouchscreenByIdx(i)
 }
 
@@ -2002,6 +2052,7 @@ func (m *Manager) initTouchscreens() {
 		m.emitPropChangedTouchscreens(m.Touchscreens)
 
 		m.handleTouchscreenChanged()
+		m.showTouchscreenDialogs()
 	})
 	if err != nil {
 		logger.Warning(err)
@@ -2010,6 +2061,8 @@ func (m *Manager) initTouchscreens() {
 	_, err = m.inputDevices.ConnectTouchscreenRemoved(func(path dbus.ObjectPath) {
 		m.removeTouchscreenByPath(path)
 		m.emitPropChangedTouchscreens(m.Touchscreens)
+		m.handleTouchscreenChanged()
+		m.showTouchscreenDialogs()
 	})
 	if err != nil {
 		logger.Warning(err)
@@ -2035,11 +2088,13 @@ func (m *Manager) initTouchscreens() {
 
 	m.initTouchMap()
 	m.handleTouchscreenChanged()
+	m.showTouchscreenDialogs()
 }
 
 func (m *Manager) initTouchMap() {
 	m.touchscreenMap = make(map[string]touchscreenMapValue)
 	m.TouchMap = make(map[string]string)
+	m.touchScreenDialogMap = make(map[string]*exec.Cmd)
 
 	value := m.settings.GetString(gsKeyMapOutput)
 	if len(value) == 0 {
@@ -2192,7 +2247,16 @@ func (m *Manager) saveConfig() error {
 	return nil
 }
 
-func (m *Manager) showTouchscreenDialog(touchscreenSerial string) error {
+func (m *Manager) showTouchscreenDialog(touchScreenUUID, touchscreenSerial string) error {
+	m.touchScreenDialogMutex.RLock()
+	existCmd, ok := m.touchScreenDialogMap[touchScreenUUID]
+	m.touchScreenDialogMutex.RUnlock()
+	if ok && existCmd != nil {
+		// 已经存在dialog，不重复打开dialog
+		logger.Debug("showTouchscreenDialog failed, touchScreen is existed:", touchScreenUUID)
+		return nil
+	}
+
 	cmd := exec.Command(cmdTouchscreenDialogBin, touchscreenSerial)
 
 	err := cmd.Start()
@@ -2200,11 +2264,20 @@ func (m *Manager) showTouchscreenDialog(touchscreenSerial string) error {
 		return err
 	}
 
+	m.touchScreenDialogMutex.Lock()
+	m.touchScreenDialogMap[touchScreenUUID] = cmd
+	m.touchScreenDialogMutex.Unlock()
+
 	go func() {
 		err = cmd.Wait()
 		if err != nil {
 			logger.Debug(err)
 		}
+		m.touchScreenDialogMutex.Lock()
+		if _, ok := m.touchScreenDialogMap[touchScreenUUID]; ok {
+			delete(m.touchScreenDialogMap, touchScreenUUID)
+		}
+		m.touchScreenDialogMutex.Unlock()
 	}()
 	return nil
 }
@@ -2228,6 +2301,10 @@ func (m *Manager) handleTouchscreenChanged() {
 		}
 	}
 
+	if len(m.Touchscreens) == 1 && len(monitors) == 1 {
+		m.associateTouch(monitors[0], m.Touchscreens[0].uuid, true)
+	}
+
 	for _, touch := range m.Touchscreens {
 		// 有配置，直接使配置生效
 		if v, ok := m.touchscreenMap[touch.uuid]; ok {
@@ -2302,10 +2379,18 @@ func (m *Manager) handleTouchscreenChanged() {
 				logger.Warning("failed to map touchscreen:", err)
 			}
 		}
+	}
+}
 
-		err := m.showTouchscreenDialog(touch.Serial)
-		if err != nil {
-			logger.Warning("shotTouchscreenOSD", err)
+// 检查当前连接的所有触控面板, 如果没有映射配置, 那么调用 OSD 弹窗.
+func (m *Manager) showTouchscreenDialogs() {
+	for _, touch := range m.Touchscreens {
+		if _, ok := m.touchscreenMap[touch.uuid]; !ok {
+			logger.Debug("cannot find touchscreen", touch.uuid, "'s configure, show OSD")
+			err := m.showTouchscreenDialog(touch.uuid, touch.Serial)
+			if err != nil {
+				logger.Warning("shotTouchscreenOSD", err)
+			}
 		}
 	}
 }
@@ -2381,3 +2466,105 @@ func (m *Manager) setAndSaveConnectInfo(connected bool, outputInfo *randr.GetOut
 		}
 	}
 }
+
+func (m *Manager) listenRotateSignal() {
+	const (
+		sensorProxyInterface  = "com.deepin.SensorProxy"
+		sensorProxyPath       = "/com/deepin/SensorProxy"
+		sensorProxySignalName = "RotationValueChanged"
+		sensorProxySignal     = "com.deepin.SensorProxy.RotationValueChanged"
+	)
+
+	systemBus, err := dbus.SystemBus()
+	if err != nil {
+		logger.Fatal(err)
+	}
+
+	err = systemBus.BusObject().AddMatchSignal(sensorProxyInterface, sensorProxySignalName,
+		dbus.WithMatchObjectPath(dbus.ObjectPath(sensorProxyPath)), dbus.WithMatchSender(sensorProxyInterface)).Err
+	if err != nil {
+		logger.Fatal(err)
+	}
+
+	m.rotationFinishChanged = true
+	signalCh := make(chan *dbus.Signal, 10)
+	systemBus.Signal(signalCh)
+	go func() {
+		for {
+			select {
+			case sig := <-signalCh:
+				var rotateScreenValue string
+				if sig.Path != sensorProxyPath || sig.Name != sensorProxySignal {
+					continue
+				}
+
+				err = dbus.Store(sig.Body, &rotateScreenValue)
+				if err != nil {
+					logger.Warning("call dbus.Store err:", err)
+					continue
+				}
+
+				if m.rotationFinishChanged {
+					m.rotationFinishChanged = false
+					m.rotationScreenTimer = time.AfterFunc(
+						time.Millisecond*time.Duration(m.rotateScreenTimeDelay), func() {
+							m.startBuildInScreenRotation(rotationScreenValue[rotateScreenValue])
+							m.rotationFinishChanged = true
+						})
+				} else {
+					m.rotationScreenTimer.Reset(time.Millisecond * time.Duration(m.rotateScreenTimeDelay))
+				}
+			}
+		}
+	}()
+}
+
+func (m *Manager) startBuildInScreenRotation(latestRotationValue uint16) {
+	// 判断旋转信号值是否符合要求
+	if latestRotationValue != randr.RotationRotate0 &&
+		latestRotationValue != randr.RotationRotate90 &&
+		latestRotationValue != randr.RotationRotate270 {
+		logger.Warningf("get Rotation screen value failed: %d", latestRotationValue)
+		return
+	}
+
+	if m.builtinMonitor != nil {
+		err := m.builtinMonitor.SetRotation(latestRotationValue)
+		if err != nil {
+			logger.Warning("call SetRotation failed:", err)
+			return
+		}
+
+		// 使旋转后配置生效
+		err = m.ApplyChanges()
+		if err != nil {
+			logger.Warning("call ApplyChanges failed:", err)
+			return
+		}
+
+		err = m.Save()
+		if err != nil {
+			logger.Warning("call Save failed:", err)
+			return
+		}
+
+		m.builtinMonitor.setPropCurrentRotateMode(RotationFinishModeAuto)
+	}
+}
+
+func (m *Manager) listenSettingsChanged() {
+	if m.settings == nil {
+		m.rotateScreenTimeDelay = defaultRotateScreenTimeDelay
+		return
+	}
+
+	gsettings.ConnectChanged(gsSchemaDisplay, "*", func(key string) {
+		switch key {
+		case gsKeyRotateScreenTimeDelay:
+			m.rotateScreenTimeDelay = m.settings.GetInt(key)
+			return
+		default:
+			return
+		}
+	})
+}
\ No newline at end of file
